## IDnow platform aar

## Notes on Version 3.3.0
- we fixed a typo in getMessages() so please make sure that the usage code reflects that change. Other than that the SDK is a drop-in replacement (fully downwards compatible).
- please check that the host app includes the dependencies like listed below.




The IDnow aar can be used to incooperate the IDnow AutoIdent platform into Android apps. The library supports API Level 21 upwards and is build against the targetSdkVersion 28 (Android 9).

### Dependencies

The IDnow framework depends on the presence of several other libraries. The current build tool used is `gradle`. Please make sure to include the following list of dependencies into your build.gradle file:

```
dependencies {

implementation fileTree(include: ['*.jar'], dir: 'libs')

...

// Network (WebSockets and REST)
implementation 'com.squareup.okhttp3:okhttp:3.11.0'
implementation 'com.squareup.okhttp3:logging-interceptor:3.11.0'
implementation 'com.squareup.retrofit2:retrofit:2.4.0'
implementation 'com.squareup.retrofit2:converter-gson:2.4.0'

// Android support libraries
implementation 'com.android.support:recyclerview-v7:28.0.0'
implementation 'com.android.support:appcompat-v7:28.0.0'
implementation 'com.android.support.constraint:constraint-layout:1.1.3'

// faster image conversion
implementation 'io.github.silvaren:easyrs:0.5.3'

// MsgPack WebSocket en-/decoding
implementation 'org.msgpack:msgpack-core:0.8.16'
implementation 'org.msgpack:jackson-dataformat-msgpack:0.8.16'

implementation 'com.airbnb.android:lottie:2.6.1'
implementation 'io.sentry:sentry-android:1.7.5'
}
```

Additionally the library needs `RenderScript` support for fast image processing. Please add this to your default config:

```
android {
    compileSdkVersion 28


    defaultConfig {
        ...
        
        minSdkVersion 21

        renderscriptTargetApi 16
        renderscriptSupportModeEnabled true

        vectorDrawables.useSupportLibrary = true
    }

    packagingOptions {
        pickFirst 'lib/armeabi-v7a/libRSSupport.so'
    }    
}

```

### Integrate the library

- please add the file idnow-android-sdk-x.x.x.aar to your projects libs folder
- add the library to your host application project as a module
- add the library to your build gradle file

```
dependencies {
    compile(name:'idnow-platform-X.X.X', ext:'aar')
    
    ...
}
```  

### Usage example

```
public class IDnowAutoIdentActivity extends AppCompatActivity implements IDnowSDK.IDnowResultListener {
    private static IDnowSDK    IDNOW_SDK    = null;
    private static IDnowConfig IDNOW_CONFIG = null;

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    
        IDNOW_SDK    = IDnowSDK.getInstance();
        IDNOW_CONFIG = new IDnowConfig();
    
        IDNOW_SDK.initialize(this, IDNOW_CONFIG);
    }
    
    private void startIdent()
    {
        String identId = "TS3-XXXXX";
        IDNOW_SDK.startIdent(identId, this);
    }
    
    @Override
    public void onIdentResult(IDnowResult iDnowResult) {
        if (iDnowResult.getIDnowStatusCode() == IDnowResult.IDnowStatusCode.ERROR) 
        {
            showBaseAlert(this, iDnowResult.getMessages());
        }
    }
}
```




